<?php
/*
Plugin Name: Address Geocoder Yandex Maps
Plugin URI: http://webmap-blog.ru
Description: A simple plugin for saving location data with posts. Conveniently converts addresses to lat/lng from the Post/Page Edit screen.
Version: 11.0
Author: Ugolnikov Sergey
Author URI: http://webmap-blog.ru
License: GPLv2+
*/


// Plugin Options 

require_once( dirname(__FILE__) . '/options.php' );

// Metabox

add_action( 'load-post.php', 'ymapsgeocoder_admin_init' );
add_action( 'load-post-new.php', 'ymapsgeocoder_admin_init' );

function ymapsgeocoder_admin_init() {
	wp_register_script( 'yandexmaps', 'http://api-maps.yandex.ru/2.0.31/?load=package.full&lang=ru-RU' );
	wp_enqueue_script( 'yandexmaps' );

	wp_register_script( 'ymaps_geocode_js', plugins_url('/address-geocoder.js', __FILE__) );
	wp_enqueue_script( 'ymaps_geocode_js' );

	add_action( 'add_meta_boxes', 'ymapsgeocoder_addboxes' );
	add_action( 'save_post', 'ymapsgeocoder_save', 10, 2 );
}

function ymapsgeocoder_addboxes($postType) {

	$types=get_post_types('','names'); 

	$alwaysexclude = array('attachment','revision','nav_menu_item');
 	$options = get_option( 'address_geocoder_options' ); 
	

	if(in_array($postType, $types) && !in_array($postType, $alwaysexclude) && $options[$postType] != 'exclude' ){


		add_meta_box('ymapsgeocoder', 'Геокодер', 'ymapsgeocoder_setup', $postType, 'normal','high');
	}
}

function ymapsgeocoder_setup( $object, $box ) { 
		
	wp_nonce_field( basename( __FILE__ ), 'ymapsgeocoder_nonce' ); ?>

	<div style="overflow: hidden; width: 100%;">
	<div id="geocodepreview" style="float: left; width: 400px; height: 200px; border: 1px solid #DFDFDF;"></div>

	<div style="margin-left: 415px">

	<p><label for="ymapsgeocoderaddress">Адрес</label><br />
		<input class="widefat" type="text" name="ymapsgeocoderaddress" id="ymapsgeocoderaddress" value="<?php echo esc_attr( get_post_meta( $object->ID, 'ymapsgeocoderaddress', true ) ); ?>" size="30" /></p>

	<p><label for="ymapsgeocoderlatlng">Координаты Lat/Lng</label><br />
			<input class="widefat" type="text" name="ymapsgeocoderlatlng" id="ymapsgeocoderlatlng" value="<?php echo esc_attr( get_post_meta( $object->ID, 'ymapsgeocoderlatlng', true ) ); ?>" size="30" /></p>

	<p><a id="geocode" class="button">Определить координаты</a></p>


	</div>
	</div>

<?php }

add_action( 'save_post', 'ymapsgeocoder_save', 10, 2 );

function ymapsgeocoder_save( $post_id, $post ) {

	if ( !isset( $_POST['ymapsgeocoder_nonce'] ) || !wp_verify_nonce( $_POST['ymapsgeocoder_nonce'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	// Address
	$new_address_value = ( isset( $_POST['ymapsgeocoderaddress'] ) ? sanitize_text_field( $_POST['ymapsgeocoderaddress'] ) : '' );
	$address_key = 'ymapsgeocoderaddress';

	$address_value = get_post_meta( $post_id, $address_key, true );

	if ( $new_address_value && '' == $address_value )
		add_post_meta( $post_id, $address_key, $new_address_value, true );

	elseif ( $new_address_value && $new_address_value != $address_value )
		update_post_meta( $post_id, $address_key, $new_address_value );

	elseif ( '' == $new_address_value && $address_value )
		delete_post_meta( $post_id, $address_key, $address_value );


	// Latlng
	$new_latlng_value = ( isset( $_POST['ymapsgeocoderlatlng'] ) ? sanitize_text_field( $_POST['ymapsgeocoderlatlng'] ) : '' );
	$latlng_key = 'ymapsgeocoderlatlng';

	$latlng_value = get_post_meta( $post_id, $latlng_key, true );

	if ( $new_latlng_value && '' == $latlng_value )
		add_post_meta( $post_id, $latlng_key, $new_latlng_value, true );

	elseif ( $new_latlng_value && $new_latlng_value != $latlng_value )
		update_post_meta( $post_id, $latlng_key, $new_latlng_value );

	elseif ( '' == $new_latlng_value && $latlng_value )
		delete_post_meta( $post_id, $latlng_key, $latlng_value );


}

// Front end

function get_geocode_latlng($postid) {
	$ymapsgeocoder = get_post_meta($postid, 'ymapsgeocoderlatlng', true);	
	return $ymapsgeocoder;
}

function get_geocode_address($postid) {
	$ymapsgeocoder = get_post_meta($postid, 'ymapsgeocoderaddress', true);	
	return $ymapsgeocoder;
}

 ?>